@@ -9,7 +9,7 @@ require 5.010000;
 
 use feature 'state';
 
-our $VERSION = '0.13';
+our $VERSION = '0.14';
 
 use Carp;
 
@@ -470,7 +470,7 @@ sub _to_json {
 
     # remove outer blessed hash and clone everything except for the
     # objects.
-    my $hash = Data::Clone::clone( { $obj->%* } );
+    my $hash = Data::Clone::clone( { %{$obj} } );
 
     # now replace the included objects
     Data::Visitor::Tiny::visit(
@@ -1347,7 +1347,7 @@ PDL::Algorithm::Center - Various methods of finding the center of a sample
 
 =head1 VERSION
 
-version 0.13
+version 0.14
 
 =head1 DESCRIPTION
 
